__version__ = "1.1.4"
__description__ = "Build fast,Test fast!"
__image__ = r"""
         /\                         .-.                 .:                      
     _  / |      .;;.    .-          .;|/:              ::                      
    (  /  |  .  ;;  `;`-'           .;   :     .-.      ;;.-.     .-.    .;.::. 
     `/.__|_.' ;;    :.            .;    :    ;   :     ;; .'   .;.-'    .;     
 .:' /    |   ;;     ;'        .:'.;     :    `:::'-' _.'`  `.   `:::' .;'      
(__.'     `-' `;.__.'         (__.'      `.                                     
"""
